// This program reads the analog voltage on PB1 and prints the prints
// the hexadecimal value of this out on the UART.  The UART pins are PA9,PA10

#include "stm32f030xx.h"
#include "serial.h"
void delay(int dly)
{
  while( dly--);
}
char UserInput[10];
/*************** 
 * ADC Test routines
 **************/  
void initADC()
{

  // Turn on GPIOB
  RCC_AHBENR |= BIT18;
  // Turn on ADC 
  RCC_APB2ENR |= BIT9;
  // Select analog mode for PB1
  GPIOB_MODER |= (BIT2+BIT3);  
  // Begin ADCCalibration
  ADC_CR |= BIT31;
  // Wait for calibration complete:  
  while ((ADC_CR & BIT31));
  // Select Channel 9
  ADC_CHSELR |= BIT9;
  // Enable the reference voltage
  ADC_CCR |= BIT22;	
  // Enable the ADC
  ADC_CR |= BIT0;  
}
int readADC()
{
  // Trigger a conversion
  ADC_CR |=  BIT2;
  // Wait for End of Conversion
  while ( (ADC_CR & BIT2) );
  // return result
  return ADC_DR;
}
void testADC()
{
  eputs("ADC: ");
  printHex(readADC());
  eputs("\r\n");
}
void initClock()
{
// This is potentially a dangerous function as it could
// result in a system with an invalid clock signal - result: a stuck system
  // Set the PLL up
  // First ensure PLL is disabled
  RCC_CR &= ~BIT24;
  while( (RCC_CR & BIT25)); // wait for PLL ready to be cleared
  // set PLL multiplier to 12 (yielding 48MHz)
  // Warning here: if system clock is greater than 24MHz then wait-state(s) need to be
  // inserted into Flash memory interface
  FLASH_ACR |= BIT0;
  FLASH_ACR &=~(BIT2 | BIT1);

  // Turn on FLASH prefetch buffer
  FLASH_ACR |= BIT4;
  RCC_CFGR &= ~(BIT21 | BIT20 | BIT19 | BIT18);
  RCC_CFGR |= (BIT21 | BIT19 ); 

  // Need to limit ADC clock to below 14MHz so will change ADC prescaler to 4
  RCC_CFGR |= BIT14;

  // Do the following to push HSI clock out on PA8 (MCO)
  // for measurement purposes.  Should be 8MHz or thereabouts (verified with oscilloscope)
  /*
  RCC_CFGR |= ( BIT26 | BIT24 );
  RCC_AHBENR |= BIT17;
  GPIOA_MODER |= BIT17;
  */

  // and turn the PLL back on again
  RCC_CR |= BIT24;        
  // set PLL as system clock source 
  RCC_CFGR |= BIT1;
}
void configPins()
{
  // Power up PORTA
  RCC_AHBENR |= BIT17;	
  GPIOA_MODER = BIT0+BIT2+BIT4+BIT6+BIT8+BIT10+BIT12+BIT14+BIT26+BIT28; // make bits 0-7,14 of port A outputs.
  // set all bits high (LEDS off) to start with
  GPIOA_ODR = 0x0;
}	
int main()
{
  int i=0;
  configPins();
  initUART(9600);
  initADC();
  enable_interrupts();
  while(1) {
    eputs("\r\nValue = ");
    printHex(readADC());
    delay(100000);    
  }
  return 0;
}
